**Example 1: 创建k8sApi异常规则导出任务**



Input: 

```
tccli tcss CreateAccessControlsRuleExportJob --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "522d7714-ef53-4940-b0ed-46d59a3cf0fd",
        "JobId": ""
    }
}
```

